        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260429 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260429 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 28 <br>2,4,5,9,11,12,13,15,17,18,19,20,21,22,24,30,32,33,34,36,37,38,39,41,42,44,49,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260429 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 23 <strong>control</strong><br>0,1,3,6,7,8,10,14,16,23,25,26,27,28,29,31,35,40,43,45,46,47,48';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260429 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260429 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 28 <br>2,4,5,9,11,12,13,15,17,18,19,20,21,22,24,30,32,33,34,36,37,38,39,41,42,44,49,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260429 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 23 <strong>control</strong><br>0,1,3,6,7,8,10,14,16,23,25,26,27,28,29,31,35,40,43,45,46,47,48';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260429 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260429 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 28 <br>2,4,5,9,11,12,13,15,17,18,19,20,21,22,24,30,32,33,34,36,37,38,39,41,42,44,49,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260429 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 23 <strong>control</strong><br>0,1,3,6,7,8,10,14,16,23,25,26,27,28,29,31,35,40,43,45,46,47,48';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260429 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260429 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 28 <br>2,4,5,9,11,12,13,15,17,18,19,20,21,22,24,30,32,33,34,36,37,38,39,41,42,44,49,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260429 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 23 <strong>control</strong><br>0,1,3,6,7,8,10,14,16,23,25,26,27,28,29,31,35,40,43,45,46,47,48';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260429 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260429 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 28 <br>2,4,5,9,11,12,13,15,17,18,19,20,21,22,24,30,32,33,34,36,37,38,39,41,42,44,49,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260429 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 23 <strong>control</strong><br>0,1,3,6,7,8,10,14,16,23,25,26,27,28,29,31,35,40,43,45,46,47,48';}
}
